Class: Wx::Sizer
- Inherits:
-
Object
- Object
- Wx::Sizer
- Defined in:
- lib/wx/classes/sizer.rb
Overview
Class for automatically managing layouts
Constant Summary collapse
- ADD_ITEM_PARAMS =
Generic method to add items, supporting positional and named arguments
[ Wx::Parameter[ :index, -1 ], Wx::Parameter[ :proportion, 0 ], Wx::Parameter[ :flag, 0 ], Wx::Parameter[ :border, 0 ], Wx::Parameter[ :user_data, nil ] ]
Instance Method Summary collapse
Instance Method Details
#add_item(item, *mixed_args) ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 |
# File 'lib/wx/classes/sizer.rb', line 11 def add_item(item, *mixed_args) args = Wx::args_as_list(ADD_ITEM_PARAMS, *mixed_args) # Call add to append if default position idx = args.shift if idx == -1 add(item, *args) else insert(idx, item, *args) end end |