Class: Wx::Size
- Inherits:
-
Object
- Object
- Wx::Size
- Defined in:
- lib/wx/classes/size.rb
Instance Method Summary collapse
-
#*(mul) ⇒ Object
Return a new Wx::Size with the width and height values both multiplied by parameter
mul, which should be a Numeric. -
#+(arg) ⇒ Object
Return a new Wx::Size with the width and height parameters both increased by parameter
arg. -
#-(arg) ⇒ Object
Return a new Wx::Size with the width and height parameters both reduced by parameter
arg. -
#/(div) ⇒ Object
Return a new Wx::Size with the width and height values both divided by parameter
div, which should be a Numeric. - #to_s ⇒ Object
Instance Method Details
#*(mul) ⇒ Object
Return a new Wx::Size with the width and height values both multiplied by parameter mul, which should be a Numeric
14 15 16 |
# File 'lib/wx/classes/size.rb', line 14 def *(mul) self.class.new( (get_x * mul).to_i, (get_y * mul).to_i ) end |
#+(arg) ⇒ Object
Return a new Wx::Size with the width and height parameters both increased by parameter arg. If arg is another Wx::Size, increase width by the other’s width and height by the other’s height; if arg is a numeric value, increase both width and height by that value.
39 40 41 42 43 44 45 46 47 48 |
# File 'lib/wx/classes/size.rb', line 39 def +(arg) case arg when self.class self.class.new( get_x + arg.get_x, get_y + arg.get_y ) when Numeric self.class.new( (get_x + arg).to_i, (get_y + arg).to_i ) else Kernel.raise TypeError, "Cannot add #{arg} to #{self.inspect}" end end |
#-(arg) ⇒ Object
Return a new Wx::Size with the width and height parameters both reduced by parameter arg. If arg is another Wx::Size, reduce width by the other’s width and height by the other’s height; if arg is a numeric value, reduce both width and height by that value.
23 24 25 26 27 28 29 30 31 32 |
# File 'lib/wx/classes/size.rb', line 23 def -(arg) case arg when self.class self.class.new( get_x - arg.get_x, get_y - arg.get_y ) when Numeric self.class.new( (get_x - arg).to_i, (get_y - arg).to_i ) else Kernel.raise TypeError, "Cannot add #{arg} to #{self.inspect}" end end |
#/(div) ⇒ Object
Return a new Wx::Size with the width and height values both divided by parameter div, which should be a Numeric
8 9 10 |
# File 'lib/wx/classes/size.rb', line 8 def /(div) self.class.new( (get_x / div).to_i, (get_y / div).to_i ) end |
#to_s ⇒ Object
2 3 4 |
# File 'lib/wx/classes/size.rb', line 2 def to_s "#<Wx::Size: (#{get_width}, #{get_height})>" end |