Class: Wx::ToolBar
- Inherits:
-
Object
- Object
- Wx::ToolBar
- Defined in:
- lib/wx/classes/toolbar.rb
Overview
A set of buttons and controls attached to one edge of a Wx::Frame
Constant Summary collapse
- ADD_ITEM_PARAMS =
Generic method to add items, supporting positional and named arguments
[ Wx::Parameter[ :position, -1 ], Wx::Parameter[ :id, -1 ], Wx::Parameter[ :label, "" ], Wx::Parameter[ :bitmap, Wx::NULL_BITMAP ], Wx::Parameter[ :bitmap2, Wx::NULL_BITMAP ], Wx::Parameter[ :kind, Wx::ITEM_NORMAL ], Wx::Parameter[ :short_help, "" ], Wx::Parameter[ :long_help, "" ], Wx::Parameter[ :client_data, nil ] ]
Instance Method Summary collapse
Instance Method Details
#add_item(*mixed_args) ⇒ Object
15 16 17 18 19 20 21 22 23 24 25 26 27 28 |
# File 'lib/wx/classes/toolbar.rb', line 15 def add_item(*mixed_args) args = Wx::args_as_list(ADD_ITEM_PARAMS, *mixed_args) if args[3] == Wx::NULL_BITMAP Kernel.raise ArgumentError, "Main button bitmap may not be NULL" end # Call add_tool to append if default position pos = args.shift if pos == -1 add_tool(*args) else insert_tool(pos, *args) end end |